@@ -396,7 +396,7 @@ class ABBAbase:
             centers = np.r_[ centers, center ]
             
         # self.centers = centers
-        strings, hashmap = symbolsAssign(labels)
+        strings, hashm = symbolsAssign(labels)
         parameters = Model(centers, centers, hashm)
         return strings, parameters
 
